==> cms-db_v0.7.9.tar.gz: admin/quirks-menu.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('frame');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<title>cms -db</title>
		<link rel="stylesheet" type="text/css" href="style.css" />
		<style type="text/css">
		<!--
		a:link, a:visited, a:active {
			font-size: 10pt;
			text-decoration: none;
		}
		a:hover {
			font-size: 10pt;
			text-decoration: underline;
		}
		-->
		</style>
	</head>
	<body>
		<h1 style="padding-bottom: 0px; margin-bottom: 0px">cms -db</h1>
		<p style="font-size: 10pt; padding-top: 0px; margin-top: 0px">(<?php locale('desc_compatversion') ?>)</p>
		<ul style="padding-left: 30px">
			<li>
				<a href="pages.php?<?php echo SID ?>" target="content">
					<?php locale('desc_pages') ?>
				</a>
			</li>
			<li>
				<a href="files.php?<?php echo SID ?>" target="content">
					<?php locale('desc_files') ?>
				</a>
			</li>
			<li>
				<a href="includes.php?<?php echo SID ?>" target="content">
					<?php locale('desc_includes') ?>
				</a>
			</li>
			<li>
				<a href="settings.php?<?php echo SID ?>" target="content">
					<?php locale('desc_settings') ?>
				</a>
			</li>
			<li>
				<a href="template.php?<?php echo SID ?>" target="content">
					<?php locale('desc_template') ?>
				</a>
			</li>
			<li>
				<a href="space.php?<?php echo SID ?>" target="content">
					<?php locale('desc_space') ?>
				</a>
			</li>
			<li>
				<a href="fileperms.php?<?php echo SID ?>" target="content">
					<?php locale('desc_fileperms') ?>
				</a>
			</li>
			<li>
				<a href="backup.php?<?php echo SID ?>" target="content">
					<?php locale('desc_backup') ?>
				</a>
			</li>
			<li>
				<a href="guestbook.php?<?php echo SID ?>" target="content">
					<?php locale('desc_guestbook') ?>
				</a>
			</li>
			<li>
				<a href="blog.php?<?php echo SID ?>" target="content">
					<?php locale('desc_blog') ?>
				</a>
			</li>
			<li>
				<a href="stats.php?<?php echo SID ?>" target="content">
					<?php locale('desc_stats') ?>
				</a>
			</li>
			<li>
				<a href="recyclebin.php?<?php echo SID ?>" target="content">
					<?php locale('desc_recyclebin') ?>
				</a>
			</li>
		</ul>
		<ul style="padding-left: 30px">
			<li>
				<a href="../" target="content">
					<?php locale('button_preview') ?>
				</a>
			</li>
			<li>
				<a href="version.php" target="content">
					<?php locale('button_about') ?>
				</a>
			</li>
			<li>
				<a href="logout.php?<?php echo SID ?>" target="_parent">
					<?php locale('button_logout') ?>
				</a>
			</li>
		</ul>
	</body>
</html>

==> cms-db_v0.8.1.tar.gz: admin/quirks-menu.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('frame');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<title>cms -db</title>
		<link rel="stylesheet" type="text/css" href="style.css" />
		<style type="text/css">
		<!--
		a:link, a:visited, a:active {
			font-size: 10pt;
			text-decoration: none;
		}
		a:hover {
			font-size: 10pt;
			text-decoration: underline;
		}
		-->
		</style>
	</head>
	<body>
		<h1 style="padding-bottom: 0px; margin-bottom: 0px">cms -db</h1>
		<p style="font-size: 10pt; padding-top: 0px; margin-top: 0px">(<?php locale('desc_compatversion') ?>)</p>
		<ul style="padding-left: 30px">
			<li>
				<a href="pages.php?<?php echo SID; csrf_protection_get_html() ?>" target="content">
					<?php locale('desc_pages') ?>
				</a>
			</li>
			<li>
				<a href="files.php?<?php echo SID; csrf_protection_get_html() ?>" target="content">
					<?php locale('desc_files') ?>
				</a>
			</li>
			<li>
				<a href="includes.php?<?php echo SID; csrf_protection_get_html() ?>" target="content">
					<?php locale('desc_includes') ?>
				</a>
			</li>
			<li>
				<a href="settings.php?<?php echo SID; csrf_protection_get_html() ?>" target="content">
					<?php locale('desc_settings') ?>
				</a>
			</li>
			<li>
				<a href="template.php?<?php echo SID; csrf_protection_get_html() ?>" target="content">
					<?php locale('desc_template') ?>
				</a>
			</li>
			<li>
				<a href="space.php?<?php echo SID; csrf_protection_get_html() ?>" target="content">
					<?php locale('desc_space') ?>
				</a>
			</li>
			<li>
				<a href="fileperms.php?<?php echo SID; csrf_protection_get_html() ?>" target="content">
					<?php locale('desc_fileperms') ?>
				</a>
			</li>
			<li>
				<a href="backup.php?<?php echo SID; csrf_protection_get_html() ?>" target="content">
					<?php locale('desc_backup') ?>
				</a>
			</li>
			<li>
				<a href="guestbook.php?<?php echo SID; csrf_protection_get_html() ?>" target="content">
					<?php locale('desc_guestbook') ?>
				</a>
			</li>
			<li>
				<a href="blog.php?<?php echo SID; csrf_protection_get_html() ?>" target="content">
					<?php locale('desc_blog') ?>
				</a>
			</li>
			<li>
				<a href="stats.php?<?php echo SID; csrf_protection_get_html() ?>" target="content">
					<?php locale('desc_stats') ?>
				</a>
			</li>
			<li>
				<a href="recyclebin.php?<?php echo SID; csrf_protection_get_html() ?>" target="content">
					<?php locale('desc_recyclebin') ?>
				</a>
			</li>
		</ul>
		<ul style="padding-left: 30px">
			<li>
				<a href="../" target="content">
					<?php locale('button_preview') ?>
				</a>
			</li>
			<li>
				<a href="version.php" target="content">
					<?php locale('button_about') ?>
				</a>
			</li>
			<li>
				<a href="logout.php?<?php echo SID; csrf_protection_get_html() ?>" target="_parent">
					<?php locale('button_logout') ?>
				</a>
			</li>
		</ul>
	</body>
</html>
